# coding=utf-8

from .config import settings

#
# TODO
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 提供通用 Request、Response 接口，使其不再依赖 Driver 实现。
#
